@@ -13,6 +13,7 @@ c      k3inout: see if a point is inside of a triangle.
 c      kxplsph: sphere and line x-point
 c      kioPrism: judge if a given point is inside of a prism
 c      kgetField:
+c      kfindField:  similar to abvoe
 c      kgetCpos:
 c      kgetBpos:
 c      kshiftB: shift blank until non blank appears
@@ -1924,3 +1925,47 @@ c             p(x) =  -p(1/x) ...
            endif
         endif
         end
+      subroutine  kfindField(buf, leng, loc1, loc2,  cond)
+      integer leng              ! input
+      character*(leng)  buf     ! input
+      integer  loc1             ! input.  
+      integer  loc2             ! output  last non blank pos. in buf
+                                !  after loc1 in buf.
+c                                  if loc2 cannot be found loc2 = 0
+      integer cond              !  input. if ==0 nothing happens
+                                !   if ==1 and loc2==0; message is given
+                                !   but execution contines
+                                !   if  == 2 and loc2==0,   message is given
+                                !  and execution stops
+
+      integer i
+
+      i = loc1
+      loc2 = 0
+      do while ( i .lt. leng )
+         if( buf(i:i) .ne. ' '  .and. buf(i+1:i+1) .eq. ' ') then
+            loc2=i
+            goto 10
+         endif
+         i = i + 1
+      enddo
+      if(buf(leng:leng) .ne.  ' ' ) then
+         loc2 = leng
+         goto 10
+      else
+         loc2 = 0
+      endif
+ 10   continue
+      if( cond .gt.  0  .and. loc2 .eq. 0 ) then
+         write(0, *) ' In kfindField: buf=',buf
+         write(0, *) ' cannot find non blank after', loc1
+         if(cond .eq. 2) stop 99999
+      endif
+
+      end
+
+      
+      
+      
+      
+      
