@@ -114,6 +114,8 @@ c             init for 1 event
       character*8 uid
       integer jcon, leng
       integer  klena
+
+       Bndryerr = 0   ! counter for bundary search failures/ event
        Cn=-1
        Firsti=.true.
        FirstC=.true.
@@ -593,7 +595,8 @@ c               You may give larger EpsLeng in input data.
 c
       if( cTrack.w.x .ne. 0. ) then
          n = 2
-         do while( cTrack.pos.x .eq. Move.boundary.x ) 
+         do while( cTrack.pos.x .eq. Move.boundary.x .and.
+     *             n .lt. 10 ) 
             cTrack.pos.x = Move.boundary.x +
      *           n*EpsLeng* cTrack.w.x   
             n = n * 2
@@ -605,7 +608,8 @@ c     *     EpsLeng* Move.Track.w.y
      *     EpsLeng* cTrack.w.y   !+++++++
       if( cTrack.w.y .ne. 0.) then
          n = 2
-         do while( cTrack.pos.y .eq. Move.boundary.y ) 
+         do while( cTrack.pos.y .eq. Move.boundary.y
+     *             .and. n .lt. 10 ) 
             cTrack.pos.y = Move.boundary.y +
      *           n*EpsLeng* cTrack.w.y   
             n = n * 2
@@ -617,7 +621,8 @@ c     *     EpsLeng* Move.Track.w.z
      *     EpsLeng* cTrack.w.z   !++++++++++
       if(cTrack.w.z .ne. 0. ) then
          n = 2
-         do while( cTrack.pos.z .eq. Move.boundary.z ) 
+         do while( cTrack.pos.z .eq. Move.boundary.z  .and.
+     *          n .lt. 10 )
             cTrack.pos.z = Move.boundary.z +
      *           n*EpsLeng* cTrack.w.z
             n = n * 2
@@ -927,7 +932,6 @@ c          standard Trace information
 
       integer k
       save xxx, yyy, zzz, kkk
-
 c
 c          Trace informaion  ccc if for putting only electorns
 c
@@ -1292,11 +1296,14 @@ c///////////////
             Move.boundary.z = cTrack.pos.z + el* cTrack.w.z
          endif 
          Move.Track.pos.x = Move.boundary.x -
-     *             EpsLeng* Move.Track.w.x
+c     *             EpsLeng* Move.Track.w.x
+     *             EpsLeng* cTrack.w.x
          Move.Track.pos.y = Move.boundary.y -
-     *             EpsLeng* Move.Track.w.y
+c     *             EpsLeng* Move.Track.w.y
+     *             EpsLeng* cTrack.w.y
          Move.Track.pos.z = Move.boundary.z -
-     *             EpsLeng* Move.Track.w.z
+c     *             EpsLeng* Move.Track.w.z
+     *             EpsLeng* cTrack.w.z
          Move.dl = sqrt(
      *          (Move.Track.pos.x-cTrack.pos.x)**2 +
      *          (Move.Track.pos.y-cTrack.pos.y)**2 +
